@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+import django
 from django.conf import settings
 from django.core.management import call_command
 
@@ -28,6 +29,13 @@ if not settings.configured:
         SYNCHRO_REMOTE = 'remote_db',
         ROOT_URLCONF = 'can be anything - tests override this',
         USE_I18N = True,
+        MIDDLEWARE_CLASSES=(
+            'django.contrib.sessions.middleware.SessionMiddleware',
+            'django.contrib.auth.middleware.AuthenticationMiddleware',
+            'django.contrib.messages.middleware.MessageMiddleware',
+        ),
     )
 
+if django.VERSION >= (1, 7):
+    django.setup()
 call_command('test', 'synchro')
