@@ -4,13 +4,18 @@ from django.contrib.contenttypes.models import ContentType
 from django.core.exceptions import ObjectDoesNotExist
 from django.core.management.base import BaseCommand, CommandError
 from django.db import transaction
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import ugettext_lazy as _t
 
 from synchro.models import Reference, ChangeLog, DeleteKey, options as app_options
 from synchro.models import ADDITION, CHANGE, DELETION, M2M_CHANGE
 from synchro.settings import REMOTE, LOCAL
 
 
+if not hasattr(transaction, 'atomic'):
+    # Django < 1.6 stub
+    transaction.atomic = transaction.commit_on_success
+
+
 def get_object_for_this_type_using(self, using, **kwargs):
     return self.model_class()._default_manager.using(using).get(**kwargs)
 ContentType.get_object_for_this_type_using = get_object_for_this_type_using
@@ -239,8 +244,8 @@ class Command(BaseCommand):
         if options['verbosity'] > 0:
             self.stdout.write(u'%s\n' % ret)
 
-    @transaction.commit_on_success
-    @transaction.commit_on_success(using=REMOTE)
+    @transaction.atomic
+    @transaction.atomic(using=REMOTE)
     def synchronize(self, *args, **options):
         if REMOTE is None:
             # Because of BaseCommand bug (#18387, fixed in Django 1.5), we cannot use CommandError
@@ -270,9 +275,9 @@ class Command(BaseCommand):
 
         if len(logs):
             app_options.last_check = last_time
-            return _('Synchronization performed successfully.')
+            return _t('Synchronization performed successfully.')
         else:
-            return _('No changes since last synchronization.')
+            return _t('No changes since last synchronization.')
 
 
 def call_synchronize(**kwargs):
